from xbbuild.info import Info
from xbutils.log import error
from pathlib import Path
from typing import Optional
from subprocess import run


def run_sphinx(info: Info, src_path: Optional[Path] = None, doc_path: Optional[Path] = None):
    if src_path is None:
        src_path = info.src_doc_path()
    if doc_path is None:
        doc_path = info.doc_path()

    if not src_path.is_dir():
        error(f"Missing doc ({src_path}")
        return False

    run(['sphinx-build', str(src_path), str(doc_path)])


def sphinx_cmd():
    run_sphinx(Info())



from xbutils.cmd import Cmd

Cmd.default_function_module = 'xbbuild'

Cmd(name='info', function=".info.info_cmd")
Cmd(name='zip-doc', function=".zip_doc.zip_doc_cmd",help='create a zip file from sphinx documentation')
Cmd(name='sphinx', function=".sphinx.sphinx_cmd",help='create documentation with sphinx')
Cmd(name='build-doc', function=".build_doc.build_doc_cmd",help ='sphinx + zip-doc')


def main():
    Cmd.main()


if __name__ == '__main__':
    main()



from xbbuild.config import cfg
from xbutils.log import warning
import re
from pathlib import Path
from typing import Optional



class Info:
    path: Path
    version: str = ''
    name: str = ''

    def __init__(self, path: Optional[Path] = None):
        self.path = Path.cwd() if path is None else path.resolve()
        if cfg.version:
            self.version = cfg.version
        if cfg.name:
            self.name = cfg.version
        self.read_egg()

    def read_egg(self):
        if self.name:
            egg_path = self.path / (self.name + '.egg-info')
        else:
            egg_list = list(i for i in self.path.glob('*.egg-info') if i.is_dir())
            if not egg_list:
                warning(f"No egg in {self.path}")
                return
            if len(egg_list) > 1:
                warning(f"Multiple eggs in {self.path} using {egg_list[0].name}")
            egg_path = egg_list[0]

        info_path = egg_path / 'PKG-INFO'
        if not info_path.exists():
            warning(f"No PKG-INFO in {egg_path}")
            return

        pkg_info = info_path.read_text()
        if not self.version:
            match = re.search(r"(?m)^Version: (\S*)\s*?$", pkg_info)
            if not match:
                warning(f"Missing Version in {info_path}")
            else:
                self.version = match.group(1)
        if not self.name:
            match = re.search(r"(?m)^Name: (\S*)\s*?$", pkg_info)
            if not match:
                warning(f"Missing Name in {info_path}")
            else:
                self.name = match.group(1)

    def pkg_name(self, ext: str = ''):
        return (self.name or 'NONAME') + '-' + (self.version or '0.0.0') + ext

    def doc_zip_path(self):
        return (self.path / cfg.out_path / self.pkg_name("-doc.zip")).resolve()

    def doc_path(self):
        return (self.path / cfg.doc_path).resolve()

    def src_doc_path(self):
        return (self.path / cfg.src_doc_path).resolve()


def info_cmd():
    i = Info()

    print("Name    :", i.name or '????')
    print("Version :", i.version or '????')
    print("Path    :", i.path)


if __name__ == '__main__':
    info_cmd()



from xbbuild.info import Info
from xbutils.log import *
from pathlib import Path
from typing import Optional
from subprocess import run


def zip_doc(info: Info, doc_path: Optional[Path] = None, zip_path: Optional[Path] = None):
    if zip_path is None:
        zip_path = info.doc_zip_path()
    if doc_path is None:
        doc_path = info.doc_path()

    if not doc_path.is_dir():
        error(f"Missing doc ({doc_path}")
        return False

    if (doc_path / 'html').is_dir():
        zip_what = 'html'
    elif (doc_path / 'index.html').is_file():
        zip_what = '.'
    else:
        error(f"Missing html in ({doc_path}")
        return False

    if not zip_path.parent.exists():
        zip_path.parent.mkdir(parents=True)

    if zip_path.exists():
        zip_path.unlink()

    run(['zip', str(zip_path), '-r', zip_what], cwd=doc_path)


def zip_doc_cmd():
    zip_doc(Info())



from setuptools import setup

setup(
    name='xbbuild',
    version='0.2.1',
    packages=['xbbuild'],
    url='https://github.com/exbee49/xbbuild',
    license='WTFPL',
    author='exbee49',
    description='Python Build utilities',
    long_description="Some Python build helper",
    long_description_content_type="text/plain",
    install_requires=['xbutils>=0.7.0'],
    zip_safe=False,
    entry_points={
        'console_scripts': ['xbbuild=xbbuild.main:main', ],
    },

    classifiers=[
        "Development Status :: 4 - Beta",
        # "license :: Public Domain :: WTFPLv2",
        "Programming Language :: Python :: 3 :: Only"
    ]
)



from xbbuild.info import Info
from xbbuild.zip_doc import zip_doc
from xbbuild.sphinx import run_sphinx
from pathlib import Path
from typing import Optional


def build_doc(info: Info, src_path: Optional[Path] = None, doc_path: Optional[Path] = None,
              zip_path: Optional[Path] = None):
    run_sphinx(info, src_path, doc_path)
    zip_doc(info, doc_path, zip_path)


def build_doc_cmd():
    build_doc(Info())



from xbutils.simple_config import SimpleConfig, Path


class Config(SimpleConfig):
    #: Package Name
    name: str = ''
    #: Package Version
    version: str = ''
    #: doc path
    doc_path: Path = Path("build/sphinx")
    #: src doc path
    src_doc_path: Path = Path("doc")
    #: packages path
    out_path: Path = Path("dist")


cfg = Config()
cfg.read_config('~/.xbbuild.cfg')
cfg.read_config('.xbbuild.cfg')
